@@ -7,6 +7,7 @@ import (
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/gopasspw/gopass/tests/gptest"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestJSONAPI(t *testing.T) {
@@ -17,9 +18,9 @@ func TestJSONAPI(t *testing.T) {
 
 	act := &jsonapiCLI{}
 
-	assert.NoError(t, act.listen(gptest.CliCtx(ctx, t)))
+	require.NoError(t, act.listen(gptest.CliCtx(ctx, t)))
 
 	b, err := act.getBrowser(ctx, gptest.CliCtx(ctx, t))
-	assert.NoError(t, err)
-	assert.Equal(t, b, "chrome")
+	require.NoError(t, err)
+	assert.Equal(t, "chrome", b)
 }
